@@ -24,17 +24,13 @@ class OpenReader(FileHandler):
         header = None
 
         with Lock(filename=self.file_path, mode=self.mode, timeout=self.timeout, check_interval=self.check_interval,
-                  fail_when_locked=self.fail_when_locked, flags=self.flags, **self.kwargs) as lines:
+                  fail_when_locked=self.fail_when_locked, flags=self.flags) as lines:
             for line in lines:
                 data.append(line)
 
-                if not header:
-                    header = converted_row
-
                 if buffer <= len(data):
                     handler(self.file_path, data, row_num - len(data) + 1, row_num, **self.kwargs)
                     data.clear()
-                    data.append(header)
 
                 row_num += 1
 
